@@ -1,4 +1,5 @@
 from django.db import models
+from django.db.models import Model
 from django.utils.translation import pgettext_lazy
 
 from .base import BaseSeoModel
@@ -21,15 +22,24 @@ class ViewSeo(SeoTagsMixin, BaseSeoModel):
     """
 
     view = models.CharField(
-        pgettext_lazy("View seo", "View"),
+        pgettext_lazy("View seo model", "View"),
         max_length=100,
         choices=SEO_VIEWS_CHOICES,
         unique=True
     )
 
     class Meta:
-        verbose_name = pgettext_lazy("Model instance seo", "View seo")
-        verbose_name_plural = pgettext_lazy("Model instance seo", "View seo")
+        verbose_name = pgettext_lazy("View seo model", "View seo")
+        verbose_name_plural = pgettext_lazy("View seo model", "View seo")
 
     def __str__(self) -> str:
         return self.title
+
+    def get_meta_image_field(self, obj: Model = None):
+        """
+        Return image field instance to get image url
+        """
+        field = self.image
+        if not field and obj:
+            field = getattr(obj, self.SEO_IMAGE_FIELD, None)
+        return field
