@@ -18,6 +18,7 @@ class ModelInstanceSeoQuerySet(QuerySet):
         Return objects for given instance
         """
         content_type = ContentType.objects.get_for_model(instance)
-        if content_type.model not in SEO_MODELS:
+        item = f'{content_type.app_label}.{content_type.model}'.lower()
+        if item not in [seo_model.lower() for seo_model in SEO_MODELS]:
             return self.none()
         return self.filter(content_type=content_type, object_id=instance.pk).distinct()
