@@ -2,22 +2,25 @@ from modeltranslation.translator import translator, TranslationOptions
 
 from .models.instance_based import ModelInstanceSeo
 from .models.view_based import ViewSeo
+from .models.url_based import UrlSeo
 
 __all__ = (
     'ModelInstanceSeoTranslationOptions',
-    'ViewSeoTranslationOptions'
+    'ViewSeoTranslationOptions',
+    'UrlSeoTranslationOptions'
 )
 
 
 class ModelInstanceSeoTranslationOptions(TranslationOptions):
     fields = (
-        'title', 
-        'keywords', 
+        'title',
+        'og_title',
+        'keywords',
         'description',
-        'alt', 
-        'h1', 
-        'top_text',
-        'bottom_text'
+        'og_description',
+        'alt',
+        'h1',
+        'seo_text'
     )
 
 
@@ -25,5 +28,10 @@ class ViewSeoTranslationOptions(ModelInstanceSeoTranslationOptions):
     pass
 
 
+class UrlSeoTranslationOptions(ModelInstanceSeoTranslationOptions):
+    pass
+
+
 translator.register(ModelInstanceSeo, ModelInstanceSeoTranslationOptions)
 translator.register(ViewSeo, ViewSeoTranslationOptions)
+translator.register(UrlSeo, UrlSeoTranslationOptions)
